import { AxiosRequestConfig } from 'axios';
import { ResponseData } from '../request/index.d';
import request from '../request/index';
import { BaseApiConfig } from './BaseApi.d';

class BaseApi {
  protected baseUrl = '';

  constructor(config: BaseApiConfig) {
    this.baseUrl = config.baseUrl;
  }

  page(data: any): Promise<ResponseData<any>> {
    return request.get(`${this.baseUrl}/page`, { params: data });
  }

  add(data: any): Promise<ResponseData<any>> {
    return request.post(`${this.baseUrl}`, data);
  }

  del(id: string | number): Promise<ResponseData<any>> {
    return request.delete(`${this.baseUrl}/${id}`);
  }

  update(data: any): Promise<ResponseData<any>> {
    return request.put(`${this.baseUrl}`, data);
  }

  get(id: string | number): Promise<ResponseData<Record<string, any>>> {
    return request.get(`${this.baseUrl}/${id}`);
  }

  list(data?: any): Promise<ResponseData<Array<any>>> {
    return request.get(`${this.baseUrl}/list`, { params: data });
  }

  async getOptions(
    data?: any,
    config = {
      labelKey: 'name',
      valueKey: 'id',
    }
  ) {
    const res = await this.list(data);
    const { labelKey, valueKey } = config;
    return res.data.map((item) => {
      return {
        label: item[labelKey],
        value: item[valueKey],
        item,
      };
    });
  }

  export(url: string, data: any): Promise<unknown> {
    return request.exportFile(`${this.baseUrl}/${url}`, data);
  }

  customizeGet(url: string, data?: any): Promise<ResponseData<any>> {
    return request.get(`${this.baseUrl}${url}`, { params: data });
  }

  customizePost(
    url: string,
    data?: any,
    config?: AxiosRequestConfig
  ): Promise<ResponseData<any>> {
    return request.post(`${this.baseUrl}${url}`, data, config);
  }

  customizePut(
    url: string,
    data?: any,
    config?: AxiosRequestConfig
  ): Promise<ResponseData<any>> {
    return request.put(`${this.baseUrl}${url}`, data, config);
  }

  customizeDel(
    url: string,
    config?: AxiosRequestConfig
  ): Promise<ResponseData<any>> {
    return request.delete(`${this.baseUrl}${url}`, config);
  }
}

export default BaseApi;
