import { computed } from 'vue';
import { useI18n } from 'vue-i18n';
import { Message } from '@arco-design/web-vue';
import enUS from '@arco-design/web-vue/es/locale/lang/en-us';
import zhCN from '@arco-design/web-vue/es/locale/lang/zh-cn';
import { LOCALE_ENUM } from '@/locale';

export default function useLocale() {
  const i18 = useI18n();
  const currentLocale = computed(() => {
    return i18.locale.value;
  });
  const changeLocale = (value: string) => {
    i18.locale.value = value;
    localStorage.setItem('arco-locale', value);
    Message.success(i18.t('navbar.action.locale'));
  };

  const arcoLocale = computed(() => {
    switch (currentLocale.value) {
      case LOCALE_ENUM.EN:
        return enUS;
      default:
        return zhCN;
    }
  });

  return {
    arcoLocale,
    currentLocale,
    changeLocale,
  };
}
