/**
 *  @description: 通用表单规则
 *  @author: 前端组 jon_潘
 *  @time: 2022-05-10 13:40:59
 */

import { isProxy, isRef, Ref, UnwrapNestedRefs } from 'vue';
import { REG_USERNAME, REG_CHINESE_CHARACTER } from '../regexp/index';

export const useUsernameRule = (
  model: Ref | UnwrapNestedRefs<any>,
  field = 'username'
) => {
  return [
    {
      required: true,
      message: '用户名必须为6-20位字母或数字',
    },
    {
      match: REG_USERNAME,
      message: '用户名必须为6-20位字母或数字',
      validator: () => {
        if (isRef(model)) {
          (model.value as Record<string, any>)[field] = (
            model.value as Record<string, any>
          )[field].replace(new RegExp(REG_CHINESE_CHARACTER, 'g'), '');
        } else if (isProxy(model)) {
          model[field] = model[field].replace(
            new RegExp(REG_CHINESE_CHARACTER, 'g'),
            ''
          );
        }
      },
    },
  ];
};

export const usePwdRule = () => {
  return [
    { required: true, message: '密码不能为空' },
    {
      match:
        /^(?=.*[a-z])(?=.*[A-Z])(?=.*[~!@#$%^&*()_+`\-={}:";'<>?,./])(?=.*\d)[\s\S]{8,20}$/,
      message: '密码必须包含英文大小写、特殊符号、数字且长度8到20位',
    },
  ];
};
