import { Ref } from 'vue';
import { Message } from '@arco-design/web-vue';
import { useRoute, useRouter } from 'vue-router';
import { omit } from 'lodash-es';
import { noop, parseRangeFields } from './helper';

export interface UseAddOrUpdateOption {
  // api相关，api优先级 pageApi > apiObj.page
  // todo ts如何定义class(typeof BaseApi)的实例对象？
  apiObj?: any; // api对象, 继承自BaseApi的实例对象
  // 详情
  getApi?: (data: any) => any;
  // 新增
  addApi?: (data: any) => any;
  // 编辑
  updateApi?: (data: any) => any;
  // 扩展方法: 格式化详情
  formatDetailsData?: (data: any) => Record<string, any>;
  // 扩展方法: 格式化提交参数
  formatSubmitData?: (data: any) => Record<string, any>;
  // model
  model: Ref<Record<string, any>>;

  [key: string]: any;
}

export default function useAddOrUpdate(options: UseAddOrUpdateOption) {
  const {
    apiObj,
    getApi,
    addApi,
    updateApi,
    model,
    formatDetailsData = noop,
    formatSubmitData = noop,
    getDetailKey,
  } = options;

  const router = useRouter();
  const route = useRoute();
  const { id } = route.params;

  const initModel = async (id: string) => {
    const res = getApi ? await getApi(id) : await apiObj.get(id);
    model.value = formatDetailsData(res.data);
  };

  if (id) {
    initModel(id as string);
  }

  function getSubmitData() {
    return formatSubmitData(
      omit(parseRangeFields(model.value), ['createTime', 'updateTime'])
    );
  }

  async function onSubmit(cb?: () => void) {
    const data = getSubmitData();
    // 根据id判断新增还是修改
    let res;
    if (data[getDetailKey]) {
      res = updateApi ? await updateApi(data) : await apiObj.update(data);
    } else {
      res = addApi ? await addApi(data) : await apiObj.add(data);
    }
    // 提示
    Message.success(res.message);
    if (cb) {
      cb();
    } else {
      router.back();
    }
  }

  return {
    initModel,
    onSubmit,
  };
}
