import { isObject, isNumber, isString, isArray } from 'lodash-es';

function firstWordToUpperCase(str: string) {
  return str.replace(/^./, (s) => {
    return s.toUpperCase();
  });
}

function firstWordToLowerCase(str: string) {
  return str.replace(/^./, (s) => {
    return s.toLowerCase();
  });
}

function getRangeKey(str = '') {
  // 抓取time/date
  const suffix = firstWordToUpperCase(
    str.replace(/(.+)*(time|date)range/i, '$2')
  );
  // 抓取time/date前面的key
  const key = str.substring(0, str.length - 9);
  const startKey = `${key}Start${suffix}`;
  const endKey = `${key}End${suffix}`;
  return [firstWordToLowerCase(startKey), firstWordToLowerCase(endKey)];
}

export const noop = (_: any) => _;

export function parseRangeFields(data: Record<string, any>) {
  const res: Record<string, any> = {};
  // eslint-disable-next-line no-restricted-syntax
  for (const condition in data) {
    // 处理时间问题
    if (
      /(timeRange)|(dateRange)$/i.test(condition) &&
      Array.isArray(data[condition])
    ) {
      if (data[condition].length > 0) {
        const [startKey, endKey] = getRangeKey(condition);
        res[startKey] = data[condition][0] as string;
        res[endKey] = data[condition][1] as string;
      }
    } else {
      res[condition] = data[condition];
    }
  }
  return res;
}

export function resetObj(data: Record<string, any>) {
  const res: Record<string, any> = {};
  // eslint-disable-next-line no-restricted-syntax
  for (const k in data) {
    if (isString(data[k]) || isNumber(data[k])) {
      data[k] = '';
    } else if (isArray(data[k])) {
      data[k] = [];
    } else if (isObject(data[k])) {
      resetObj(data[k]);
    } else {
      // console.warn('unknow type:', data[k], data);
    }
  }
  return res;
}
