import { REG_URL } from '@/regexp';

// 自动扫描modules文件夹下的路由文件
const routers = Object.values(import.meta.globEager('./modules/*.ts')).map(
  (item) => item.default
);

export const authRouter = routers
  .filter((item) => item.meta?.requiresAuth !== false)
  .sort((a, b) => a.meta?.sort - b.meta?.sort);

const routerMap = new Map<string, any>([
  [
    '一级菜单',
    {
      path: '/',
      component: () => import('../layout/page-layout.vue'),
      name: 'PageLayout',
      isLayout: true,
    },
  ],
  [
    '空路由',
    {
      path: '/',
      component: () => import('../layout/empty-layout.vue'),
      name: 'EmptyLayout',
      isLayout: true,
    },
  ],
  [
    'iframe',
    {
      path: '/iframe',
      component: () => import('../views/iframe/index.vue'),
      name: 'Iframe',
      /* props: (route) => {
        return { url: route.meta.extra.iframeSrc };
      }, */
      isLayout: false,
      /**
       * dynamicForm中field字段值不能为以下字段
            id,
            parentId,
            icon,
            type,
            name,
            path,
            sort,
       */
      dynamicForm: [
        {
          label: '内嵌地址',
          field: 'iframeSrc',
          rules: [
            {
              required: true,
              message: '地址不能为空',
            },
            {
              match: REG_URL,
              message: '地址不合法',
            },
          ],
        },
      ],
    },
  ],
]);

authRouter.forEach((router) => {
  router?.children?.forEach((item: any) => {
    const { title } = item.meta;
    // 如果key已存在
    if (routerMap.has(title)) {
      const { warn } = console;
      warn(title, '路由已存在');
      warn('新路由将覆盖原路由');
      warn('请检查路由文件');
      warn(routerMap.get(title), ' => ', item);
    }

    routerMap.set(title, {
      name: item.name,
      path: item.path,
      component: item.component,
      isLayout: false,
    });
  });
});

export { routerMap };

export default routers;
