import { createRouter, createWebHashHistory, RouteRecordRaw } from 'vue-router';
import 'nprogress/nprogress.css';
import { authRouter } from './auth-router';
import routerInterceptor from './interceptor';

const router = createRouter({
  history: createWebHashHistory(),
  routes: [
    {
      path: '/:pathMatch(.*)*',
      name: 'NotFound',
      hidden: true,
      redirect: '/404',
    },
    {
      path: '/login',
      name: 'login',
      hidden: true,
      component: () => import('@/views/login/index.vue'),
    },
    {
      path: '/message',
      component: () => import('@/layout/page-layout.vue'),
      hidden: true,
      children: [
        {
          path: '/message-center',
          name: 'messageCenter',
          component: () => import('@/views/messageCenter/index.vue'),
          meta: {
            title: '消息中心',
          },
        },
      ],
    },
    {
      path: '/',
      component: () => import('@/layout/page-layout.vue'),
      hidden: true,
      children: [
        {
          path: '/403',
          name: '403',
          component: () => import('@/views/exception/403/index.vue'),
          meta: { breadcrumb: false },
        },
        {
          path: '/404',
          name: '404',
          component: () => import('@/views/exception/404/index.vue'),
          meta: { breadcrumb: false },
        },
        {
          path: '/500',
          name: '500',
          component: () => import('@/views/exception/500/index.vue'),
          meta: { breadcrumb: false },
        },
      ],
    },
    {
      path: '/',
      component: () => import('@/layout/empty-layout.vue'),
      children: [...authRouter],
    },
  ] as unknown as Array<RouteRecordRaw>,
  scrollBehavior() {
    return { top: 0 };
  },
});

routerInterceptor(router);

export default router;
