import { defineStore } from 'pinia';
import { pick } from 'lodash-es';
import { useFavicon, useTitle } from '@vueuse/core';
import defaultSettings from '@/config/settings.json';
import SysConfigApi from '@/views/system/setting/api/SysConfigApi';
import IgnoreConfigApi from '@/api/module/IgnoreConfigApi';
import { MENU_TYPE } from '@/constant/menu';
import { isString } from '@arco-design/web-vue/es/_utils/is';
import { AppState } from './types';

const icon = useFavicon();
const title = useTitle();

// 系统设置id查询写死
const sysSettingId = 1;
const sysSettingKeys = [
  'platformName',
  'browserLogo',
  'platformLogo',
  'copyrightInfo',
];

const useAppStore = defineStore('app', {
  state: (): AppState => ({
    ...defaultSettings,
    menuType: MENU_TYPE.MENU,
    navMenuType: MENU_TYPE.NAV_MENU,
    loading: false,
    updateApp: false,
    curOperate: '',
  }),

  getters: {
    appCurrentSetting(state: AppState): AppState {
      return { ...state };
    },
  },
  actions: {
    toggleMenuType() {
      this.menuType = Object.is(this.menuType, MENU_TYPE.MENU)
        ? MENU_TYPE.TOP_MENU
        : MENU_TYPE.MENU;
    },
    setloadding(load: boolean) {
      this.loading = load;
    },
    setUpdateStatus(status: boolean) {
      this.updateApp = status;
    },
    async initSystemSetting() {
      const res = await IgnoreConfigApi.get(sysSettingId);
      this.updateSettings(pick(res.data, sysSettingKeys));
      icon.value = res.data.browserLogo;
      title.value = res.data.platformName;
    },

    async updateSystemSetting(data: any) {
      const res = await SysConfigApi.update({
        id: sysSettingId,
        ...data,
      });
      this.updateSettings(pick(data, sysSettingKeys));
      icon.value = data.browserLogo;
      title.value = data.platformName;
      return res;
    },
    // Update app settings
    updateSettings(partial: Partial<AppState>) {
      // @ts-ignore-next-line
      this.$patch(partial);
    },

    // Change theme color
    toggleTheme(dark: boolean) {
      if (dark) {
        this.theme = 'dark';
        document.body.setAttribute('arco-theme', 'dark');
      } else {
        this.theme = 'light';
        document.body.removeAttribute('arco-theme');
      }
    },
    // dialogo oprate status  ADD = 0,EDIT = 1,SHOW = 2,
    updateCurOperate(val: number | string) {
      this.curOperate = val;
    },
    initConfig() {
      const config: any = JSON.parse(localStorage.getItem('config') || '{}');
      console.log('初始化本地配置', config);
      if (!Object.keys(config).length) return;
      const regular = new FontFace(
        'SourceHanSansCN-Regular',
        `url(${config.minio}/ctis/cms/SourceHanSansCN-Regular.otf)`
      );
      regular.load().then((loadFace) => {
        (document.fonts as any).add(loadFace);
      });
      const script = document.createElement('script');
      script.src = config.screenServerUrl;
      document.body.appendChild(script);
    },
  },
});

export default useAppStore;
