export const obj2propsList = (
  obj: Record<string, string>,
  toNumber = false
) => {
  return Object.keys(obj).map((key: any) => {
    return {
      label: (obj as Record<string, any>)[key],
      value: toNumber ? +key : key,
    };
  });
};

const getChildrenIds = (
  list: Record<string, any>[],
  field = 'children',
  initArg: string[] = []
) => {
  list.forEach((item) => {
    if (item[field]) {
      // 后台可能不会给children
      initArg.push(...item[field].map((item: any) => item.id));
    }
    getChildrenIds(item.children || [], field, initArg);
  });
  return initArg;
};

export const getIdListByChildField = (
  list: Record<string, any>[],
  field?: string,
  initArg: any[] = []
): Array<string | number> => {
  initArg = list.map((item) => item.id);
  return getChildrenIds(list, field, initArg);
};

/**
 * 构造树型结构数据
 * @param {*} data 数据源
 * @param {*} id id字段 默认 'id'
 * @param {*} parentId 父节点字段 默认 'parentId'
 * @param {*} children 子节点字段 默认 'children'
 */
export const handleTree = (
  data: any[],
  id?: string,
  parentId?: string,
  children?: string
) => {
  const config = {
    id: id || 'id',
    parentId: parentId || 'parentId',
    childrenList: children || 'children',
  };

  const childrenListMap: any = {};
  const nodeIds: any = {};
  const tree: any[] = [];
  data.forEach((d) => {
    const parentId = d[config.parentId];
    if (childrenListMap[parentId] == null) {
      childrenListMap[parentId] = [];
    }
    nodeIds[d[config.id]] = d;
    childrenListMap[parentId].push(d);
  });

  data.forEach((d) => {
    const parentId = d[config.parentId];
    if (nodeIds[parentId] == null) {
      tree.push(d);
    }
  });

  tree.forEach((t) => {
    adaptToChildrenList(t);
  });
  function adaptToChildrenList(t: any) {
    if (childrenListMap[t[config.id]] != null) {
      t[config.childrenList] = childrenListMap[t[config.id]];
    }
    if (t[config.childrenList]) {
      t[config.childrenList].forEach((c: any) => adaptToChildrenList(c));
    }
  }
  return tree;
};
