import { useUserStore } from '@/store';
import { EXAMINE_STATUS } from '@/constant/appointment';
import { ComputedRef, Ref } from 'vue';

const userStore = useUserStore();

export const searchConfig = [
  { label: '车牌信息', field: 'vehNo', placeholder: '请输入车牌信息' },
  {
    label: '预约日期',
    field: 'timeRange',
    type: 'date-picker',
    componentConfig: {
      'mode': 'daterange',
      'showTime': false,
      'allow-clear': false,
    },
  },
  {
    label: '审核状态',
    field: 'status',
    type: 'select',
    placeholder: '请选择审核状态',
    options: [
      EXAMINE_STATUS.START,
      EXAMINE_STATUS.SUCCESS,
      EXAMINE_STATUS.ERROR,
      EXAMINE_STATUS.FINISH,
    ],
  },
  { label: '主运单号', field: 'mawbNo', placeholder: '请输入主运单号' },
  {
    label: '代理代码',
    field: 'fwdNo',
    placeholder: '请输入代理代码',
    show: userStore.isSuperAdmin,
  },
];

export const getFormConfiguration = (
  vehbookVtype: Ref<string[]>,
  vehbookInhslot: Ref<string[]>,
  iwvehType: Ref<string[]>
) => {
  return [
    {
      label: '车牌信息',
      field: 'vehNo',
      isEdit: true,
      clo: 12,
      maxLength: 10,
      rules: { required: true, message: '车牌信息不能为空' },
    },
    {
      label: '车辆信息',
      field: 'vehTypes',
      type: 'select',
      isEdit: true,
      clo: 12,
      options: vehbookVtype,
      rules: { required: true, message: '车辆信息不能为空' },
    },
    {
      label: '预约日期',
      field: 'audDate',
      type: 'picker',
      clo: 12,
      rules: { required: true, message: '预约日期不能为空' },
    },
    {
      label: '预约时间段',
      field: 'audTseg',
      type: 'select',
      clo: 12,
      options: vehbookInhslot,
      rules: { required: true, message: '预约时间段不能为空' },
    },
    {
      label: '联系人',
      field: 'drvName',
      isEdit: true,
      clo: 12,
      maxLength: 20,
      rules: { required: true, message: '联系人不能为空' },
    },
    {
      label: '联系人电话',
      field: 'drvTel',
      isEdit: true,
      clo: 12,
      maxLength: 11,
      rules: { required: true, message: '联系人电话不能为空' },
    },
    {
      label: '提货类型',
      field: 'bsType',
      type: 'select',
      clo: 12,
      options: iwvehType,
      rules: { required: true, message: '提货类型不能为空' },
    },
    {
      label: '垛口',
      field: 'dockNo',
      clo: 12,
      hidden: true,
    },
  ];
};
