import useTableIndex from '@/hooks/tableIndex';
import useTableOperate from '@/hooks/tableOperate';
import { BILL_STATUS, BILL_STATUS_MAP } from '@/constant/bill';
import { COLUMNS_WIDTH, TABLE_TOOLTIP, TABLE_ELLIPSIS } from '@/constant/base';

// 表格
export const columns = useTableOperate(
  useTableIndex([
    {
      title: '结算编码',
      dataIndex: 'mtBcode',
      // width: COLUMNS_WIDTH.XL,
      tooltip: TABLE_TOOLTIP,
      ellipsis: TABLE_ELLIPSIS,
    },
    {
      title: '结算方式',
      dataIndex: 'payCode',
      width: COLUMNS_WIDTH.SM,
    },
    {
      title: '结算日期',
      dataIndex: 'acctDate',
      width: COLUMNS_WIDTH.LG,
    },
    {
      title: '付费主体',
      dataIndex: 'tgtFullName',
      width: COLUMNS_WIDTH.SM,
    },
    {
      title: '付费对象',
      dataIndex: 'refName',
      // width: COLUMNS_WIDTH.XL,
      tooltip: TABLE_TOOLTIP,
      ellipsis: TABLE_ELLIPSIS,
    },
    {
      title: '总计收费',
      dataIndex: 'tlPrice',
      width: COLUMNS_WIDTH.BASE,
    },
    {
      title: '费用名称',
      dataIndex: 'acctName',
      // width: COLUMNS_WIDTH.XL,
      tooltip: TABLE_TOOLTIP,
      ellipsis: TABLE_ELLIPSIS,
    },
    {
      title: '是否确认',
      dataIndex: 'tgtCfmStatus',
      fixed: 'right',
      width: COLUMNS_WIDTH.BASE,
      render(scope: any) {
        return h(
          'span',
          {
            class:
              scope.record.tgtCfmStatus === BILL_STATUS.NO
                ? 'text-danger'
                : 'text-success',
          },
          BILL_STATUS_MAP[scope.record.tgtCfmStatus as BILL_STATUS] || '--'
        );
      },
    },
    {
      title: '异议',
      dataIndex: 'objection',
      width: COLUMNS_WIDTH.SM,
      render(scope: any) {
        return h(
          'span',
          {
            class: {
              'text-danger': !!scope.record.objection,
            },
          },
          scope.record.objection ? '有' : '无'
        );
      },
    },
  ]),
  { width: COLUMNS_WIDTH.XL, align: 'center' }
);

export const detailColumns = useTableIndex(
  [
    {
      title: '收费项目类型',
      dataIndex: 'acctCode',
      align: 'center',
      width: COLUMNS_WIDTH.BASE,
      tooltip: TABLE_TOOLTIP,
      ellipsis: TABLE_ELLIPSIS,
    },
    {
      title: '收费项目',
      dataIndex: 'acctName',
      align: 'center',
      width: COLUMNS_WIDTH.LG,
      tooltip: TABLE_TOOLTIP,
      ellipsis: TABLE_ELLIPSIS,
    },
    {
      title: '单价',
      dataIndex: 'unitPrice',
      align: 'center',
      width: COLUMNS_WIDTH.XS,
      render(scope: any) {
        return h('span', scope.record.unitPrice || '--');
      },
    },
    {
      title: '数量',
      dataIndex: 'amt1',
      align: 'center',
      width: COLUMNS_WIDTH.XS,
      render(scope: any) {
        return h('span', scope.record.amt1 || '--');
      },
    },
    {
      title: '费用',
      dataIndex: 'tlPrice',
      align: 'center',
      width: COLUMNS_WIDTH.XS,
    },
    {
      title: '备注',
      dataIndex: 'remark',
      align: 'center',
      width: COLUMNS_WIDTH.BASE,
      tooltip: TABLE_TOOLTIP,
      ellipsis: TABLE_ELLIPSIS,
    },
    {
      title: '异议内容',
      dataIndex: 'objection',
      align: 'center',
      tooltip: TABLE_TOOLTIP,
      ellipsis: TABLE_ELLIPSIS,
      width: COLUMNS_WIDTH.BASE,
      render(scope: any) {
        return h('span', scope.record.objection || '--');
      },
    },
    {
      title: '操作人',
      dataIndex: 'applyNo',
      align: 'center',
      width: COLUMNS_WIDTH.SM,
      render(scope: any) {
        return h('span', scope.record.applyNo || '--');
      },
    },
    {
      title: '操作意见',
      dataIndex: 'replyDesc',
      align: 'center',
      width: COLUMNS_WIDTH.BASE,
      render(scope: any) {
        return h('span', scope.record.replyDesc || '--');
      },
    },
    {
      title: '操作',
      width: COLUMNS_WIDTH.SM,
      align: 'center',
      slotName: 'oprate',
    },
  ],
  { align: 'center' }
);
