import { useUserStore } from '@/store';
import { ComputedRef, Ref, reactive } from 'vue';
import { validatorNum, validatorNotReqNum } from '@/regexp';
import { endsWith } from 'lodash-es';

const userStore = useUserStore();
const englishAndNumber = /^[A-Za-z0-9]*$/; // 字母和数字
const positiveInteger = /^[0-9]\d*$/; // 只匹配正整数
const oneDecimal = /^\d+(\.\d{1})?$/; // 1位小数
const twoDecimal = /^\d+(\.\d{1,2})?$/; // 2位小数
const threeEngLish = /^[A-Za-z]{3}$/; // 3 位英文
const twoEngLish = /^[a-zA-Z]{2}$/; // 两位英文
const GOODSNAMEEN = /^[A-Z0-9.\-\s]+$/; // 只能包含大写字母、数字、点、连字符和空格
const ENGLISH_LETTER_CHARACTER_NUMBER = /^[A-Za-z0-9\s.,!?()&@#%+-]*$/; // 部分英文字符和数字和英文
// 查询条件
export const setFiltrateData = (waybillStatusMap: Ref<string[]>) => {
  return [
    { label: '主运单号', field: 'mawbNo', placeholder: '请输入主运单号' },
    { label: '分运单号', field: 'hawbNo', placeholder: '请输入分运单号' },
    { label: '航班号', field: 'fltNo', placeholder: '请输入航班号' },
    {
      label: '航班日期',
      field: 'timeRange',
      type: 'date-picker',
      componentConfig: {
        'mode': 'daterange',
        'showTime': false,
        'allow-clear': false,
      },
    },
    {
      label: '收单状态',
      field: 'status',
      placeholder: '请选择收单状态',
      type: 'select',
      options: waybillStatusMap,
    },
    {
      label: '代理代码',
      field: 'agtNo',
      placeholder: '请输入代理代码',
      show: userStore.isSuperAdmin,
    },
  ];
};

// 主要信息——运单信息配置 ,编辑页面
export const mainOrderInfo = [
  { label: '主运单号', field: 'mawbNo', clo: 6 },
  { label: '分运单号', field: 'hawbNo', clo: 6 },
  { label: '货运代理', field: 'agtNo', clo: 6 },
  { label: '承运人', field: 'crrNo', clo: 6 },
  { label: '货物性质', field: 'goodsType', clo: 6, hidden: true },
  { label: 'SLAC', field: 'slacDec', clo: 6 },
  { label: '单证确认状态', field: 'wbcStatus', clo: 12, hidden: true },
  { label: '申报件数', field: 'pcsDec', clo: 6 },
  { label: '申报重量', field: 'wtDec', clo: 6, unit: 'KG' },
  {
    type: 'input',
    label: '计费重量',
    field: 'wtChg',
    clo: 12,
    unit: 'KG',
    rules: {
      required: true,
      message: '计费重量不能为空',
    },
  },
  {
    'type': 'input',
    'label': '中文品名',
    'field': 'goodsName',
    'clo': 12,
    'max-length': 65,
    'placeholder': '不能超过65个字符',
    'rules': {
      required: true,
      message: '中文品名不能为空',
      // validator(value: string, callback: (message?: string) => void) {
      //   if (currentFrom.value?.goodsName || currentFrom.value?.goodsNameEn) {
      //     callback();
      //   } else {
      //     callback('中文品名、英文品名选填一项');
      //   }
      // },
    },
  },
  {
    'type': 'input',
    'label': '英文品名',
    'field': 'goodsNameEn',
    'clo': 12,
    'max-length': 65,
    'placeholder': '不能超过65个字符',
    'rules': {
      required: true,
      message: '英文品名不能为空',
      // validator(value: string, callback: (message?: string) => void) {
      //   if (currentFrom.value?.goodsName || currentFrom.value?.goodsNameEn) {
      //     callback();
      //   } else {
      //     callback('中文品名、英文品名选填一项');
      //   }
      // },
    },
  },
  { label: '特货代码', field: 'shCodes', clo: 12 },
  { label: 'UN代码', field: 'undgCodes', clo: 12 },
  { label: '鉴定报告', field: 'appraisalReport', clo: 12 },
  { label: '操作注意', field: 'handleInfo', clo: 12, hidden: true },
];

// 主要信息——航班信息配置
export const mainFlyInfo = [
  { label: '航班号', field: 'fltNo', clo: 6 },
  { label: '航班日期', field: 'fltDate', clo: 6 },
  { label: '起始站', field: 'orgnNo', clo: 6 },
  { label: '终点站', field: 'destNo', clo: 6 },
  { label: '第一目的站', field: 'rtgTo1', clo: 6, hidden: true },
  { label: '第一承运人', field: 'rtgBy1', clo: 6, hidden: true },
  { label: '第二目的站', field: 'rtgTo2', clo: 6, hidden: true },
  { label: '第二承运人', field: 'rtgBy2', clo: 6, hidden: true },
  { label: '第三目的站', field: 'rtgTo3', clo: 6, hidden: true },
  { label: '第三承运人', field: 'rtgBy3', clo: 6, hidden: true },
];

// 联系方式——运单信息
export const contactOrderInfo = [
  { label: '主运单号', field: 'mawbNo', clo: 6 },
  { label: '分运单号', field: 'hawbNo', clo: 6 },
  { label: '货运代理', field: 'agtNo', clo: 6 },
];

// 避免陷入死循环
let cneTelNoValidate = true;
let cneFaxNoValidate = true;
let shpTelNoValidate = true;
let shpFaxNoValidate = true;

/**
 * @description:获取联系方式——托运人信息
 * @param {object} currentFrom 表单数据
 * @param {object} formRef from dom ref
 * @return: 托运人信息配置
 */
export const getShipperConfig = (
  currentFrom: Ref<Record<string, any>>,
  formRef: Ref<any>
) => {
  return [
    {
      'label': '企业名称',
      'field': 'shpName',
      'clo': 12,
      'max-length': 65,
      'placeholder': '请输入65个字符以内',
      'rules': { required: true, message: '企业名称不能为空' },
    },
    {
      'label': '详细地址',
      'field': 'shpAddr',
      'clo': 12,
      'max-length': 35,
      'placeholder': '请输入详细地址(35个字符以内)',
      'rules': { required: true, message: '详细地址不能为空' },
    },
    {
      'label': '国家',
      'field': 'shpCont',
      'clo': 6,
      'max-length': 20,
      'placeholder': '请输入国家(20个字符以内)',
      'rules': { required: true, message: '国家不能为空' },
    },
    {
      'label': '州省',
      'field': 'shpProv',
      'clo': 6,
      'max-length': 20,
      'placeholder': '请输入州省(20个字符以内)',
    },
    {
      'label': '城市',
      'field': 'shpCity',
      'clo': 6,
      'max-length': 20,
      'placeholder': '请输入城市(20个字符以内)',
    },
    {
      'label': '邮编',
      'field': 'shpPostNo',
      'clo': 6,
      'max-length': 6,
    },
    {
      'label': '电话号码',
      'field': 'shpTelNo',
      'clo': 6,
      'max-length': 20,
      'placeholder': '电话号码、传真号码选填一项',
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (currentFrom.value?.shpTelNo || currentFrom.value?.shpFaxNo) {
            if (shpTelNoValidate) {
              shpFaxNoValidate = false;
              formRef.value.validateField('shpFaxNo');
            }
            shpTelNoValidate = true;
            callback();
          } else {
            callback('电话号码、传真号码选填一项');
          }
        },
      },
    },
    {
      'label': '传真号码',
      'field': 'shpFaxNo',
      'clo': 6,
      'max-length': 8,
      'placeholder': '电话号码、传真号码选填一项',
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (currentFrom.value?.shpTelNo || currentFrom.value?.shpFaxNo) {
            if (shpFaxNoValidate) {
              shpTelNoValidate = false;
              formRef.value.validateField('shpTelNo');
            }
            shpFaxNoValidate = true;
            callback();
          } else {
            callback('电话号码、传真号码选填一项');
          }
        },
      },
    },
    {
      'label': '托运人账号',
      'field': 'shpActNo',
      'clo': 6,
      'max-length': 20,
      'placeholder': '20个字符以内',
    },
  ];
};

/**
 * @description:获取联系方式——收货人信息
 * @param {object} currentFrom 表单数据
 * @param {object} formRef from dom ref
 * @return: 收货人信息配置
 */
export const getGooderConfig = (
  currentFrom: Ref<Record<string, any>>,
  formRef: Ref<any>
) => {
  return [
    {
      'label': '企业名称',
      'field': 'cneName',
      'clo': 12,
      'max-length': 65,
      'placeholder': '请输入65个字符以内',
      'rules': { required: true, message: '企业名称不能为空' },
    },
    {
      'label': '详细地址',
      'field': 'cneAddr',
      'clo': 12,
      'max-length': 35,
      'placeholder': '请输入详细地址(35个字符以内)',
      'rules': { required: true, message: '详细地址不能为空' },
    },
    {
      'label': '国家',
      'field': 'cneCont',
      'clo': 6,
      'max-length': 20,
      'placeholder': '请输入国家(20个字符以内)',
      'rules': { required: true, message: '国家不能为空' },
    },
    {
      'label': '州省',
      'field': 'cneProv',
      'clo': 6,
      'max-length': 20,
      'placeholder': '请输入洲省(20个字符以内)',
    },
    {
      'label': '城市',
      'field': 'cneCity',
      'clo': 6,
      'max-length': 20,
      'placeholder': '请输入城市(20个字符以内)',
    },
    {
      'label': '邮编',
      'field': 'cnePostNo',
      'clo': 6,
      'max-length': 50,
    },
    {
      'label': '电话号码',
      'field': 'cneTelNo',
      'clo': 6,
      'max-length': 11,
      'placeholder': '电话号码、传真号码选填一项',
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (currentFrom.value?.cneTelNo || currentFrom.value?.cneFaxNo) {
            if (cneTelNoValidate) {
              cneFaxNoValidate = false;
              formRef.value.validateField('cneFaxNo');
            }
            cneTelNoValidate = true;
            callback();
          } else {
            callback('电话号码、传真号码选填一项');
          }
        },
      },
    },
    {
      'label': '传真号码',
      'field': 'cneFaxNo',
      'clo': 6,
      'max-length': 8,
      'placeholder': '电话号码、传真号码选填一项',
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (currentFrom.value?.cneTelNo || currentFrom.value?.cneFaxNo) {
            if (cneFaxNoValidate) {
              cneTelNoValidate = false;
              formRef.value.validateField('cneTelNo');
            }
            cneFaxNoValidate = true;
            callback();
          } else {
            callback('电话号码、传真号码选填一项');
          }
        },
      },
    },
    {
      'label': '托运人账号',
      'field': 'cneActNo',
      'clo': 6,
      'max-length': 20,
      'placeholder': '20个字符以内',
    },
  ];
};

// 运单明细——运单信息
export const waybillOrderInfo = [
  { label: '主运单号', field: 'mawbNo', clo: 6 },
  { label: '分运单号', field: 'hawbNo', clo: 6 },
  { label: '货运代理', field: 'agtNo', clo: 12 },
  {
    label: '代理名称',
    field: 'agtName',
    type: 'input',
    clo: 6,
    hidden: true,
    rules: { required: true, message: '代理名称不能为空' },
  },
  {
    label: '代理IATA代码',
    field: 'agtIataNo',
    type: 'input',
    clo: 6,
    hidden: true,
  },
  { label: '代理账号', field: 'agtActNo', type: 'input', clo: 6, hidden: true },
  {
    label: '代理结算注意',
    field: 'agtActInfo',
    type: 'input',
    clo: 6,
    hidden: true,
  },
];

/**
 * @description:获取运单明细——支付信息
 * @param {Array} currencyList 币制代码
 * @param {Array} chgsList 付费方式
 * @return: 收货人信息配置
 */
export const getPayConfig = (
  currencyList: Ref<string[]>,
  chgsList: Ref<string[]>
) => {
  return [
    {
      label: '币制代码',
      field: 'curNo',
      clo: 8,
      type: 'select',
      options: currencyList,
      allowCreate: false,
      required: true,
      // rules: { required: mainFlag, message: '币制代码不能为空' },
    },
    {
      label: '运费/价值付款方式',
      field: 'wtValChgs',
      clo: 8,
      type: 'select',
      options: chgsList,
      allowCreate: true,
      required: true,
      // rules: { required: mainFlag, message: '运费/价值付款方式不能为空' },
    },
    {
      label: '其他费用付款方式',
      field: 'othChgs',
      clo: 8,
      type: 'select',
      options: chgsList,
      allowCreate: true,
      required: true,
      // rules: { required: mainFlag, message: '其他费用付款方式不能为空' },
    },
    {
      label: '运输声明价值',
      field: 'crgDecVal',
      clo: 8,
      placeholder: '请输入运输声明价值',
    },
    {
      label: '海关声明价值',
      field: 'cusDecVal',
      clo: 8,
      placeholder: '请输入海关声明价值',
    },
    {
      label: '保险金额',
      field: 'insAmt',
      clo: 8,
      placeholder: '请输入保险金额',
    },
  ];
};

/**
 * @description:获取联系方式——收货人信息
 * @param {object} currentFrom 表单数据
 * @return: 收货人信息配置
 */
export const getOtherInfo = (currentFrom: Ref<Record<string, any>>) => {
  return [
    {
      label: '运费',
      field: 'WtChg',
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (currentFrom.value?.ccWtChg || currentFrom.value?.ppWtChg) {
            callback();
          } else {
            callback('运费到付、预付选填一项');
          }
        },
      },
    },
    { label: '附加费', field: 'VlChg' },
    { label: '税费', field: 'TxChg' },
    { label: '代理人费', field: 'AgChg' },
    { label: '承运人费', field: 'CrChg' },
  ];
};

//
export const waybillPrice = [
  {
    label: '件数',
    field: 'pcs',
    clo: 8,
    rules: [{ required: true, message: '件数不能为空' }, validatorNum],
  },
  {
    label: '毛重',
    field: 'wtGrs',
    clo: 8,
    rules: [{ required: true, message: '毛重不能为空' }, validatorNum],
  },
  {
    label: '计费重量',
    field: 'wtChg',
    clo: 8,
    rules: [{ required: true, message: '计费重量不能为空' }, validatorNum],
  },
  {
    label: '类型',
    field: 'rtCls',
    clo: 8,
    rules: [{ required: true, message: '类型不能为空' }],
  },
  {
    label: '费率',
    field: 'rtVal',
    clo: 8,
    rules: [{ required: true, message: '费率不能为空' }, validatorNum],
  },
  {
    label: '总运价',
    field: 'tlVal',
    clo: 8,
    rules: [{ required: true, message: '总运价不能为空' }, validatorNum],
  },
  {
    label: '商品代码',
    field: 'commNo',
    clo: 8,
    rules: [{ required: true, message: '商品代码' }],
  },
  {
    'label': '货物描述',
    'field': 'nDesc',
    'clo': 16,
    'max-length': 65,
    'rules': [{ required: true, message: '货物描述不能为空' }],
  },
];

// TODO: 以下是新功能

// 主运单信息
export const getMainWaybillInfo = (currentFrom) => {
  return [
    {
      'type': 'input',
      'label': '中文品名',
      'field': 'goodsName',
      'clo': 12,
      'max-length': 200,
      'rules': {
        required: true,
        message: '必填项不能为空',
      },
    },
    {
      'type': 'input',
      'label': '英文品名',
      'field': 'goodsNameEn',
      'format': 'C',
      'clo': 12,
      'max-length': 50,
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          // if (value.length > 20) {
          //   callback('长度不能超过20位');
          // }
          if (GOODSNAMEEN.test(value)) {
            callback();
          } else {
            callback('英文品名只能包含大写字母、数字、点、连字符和空格');
          }
        },
      },
    },
    {
      label: '主运单号',
      field: 'mawbNo',
      clo: 6,
      rules: {
        required: true,
      },
    },
    {
      label: '主单件数',
      field: 'pcsDec',
      format: 'E',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          if (
            positiveInteger.test(value) &&
            Number(value) >= 0 &&
            Number(value) < 10000
          ) {
            callback();
          } else {
            callback('只能是正整数，并且小于10000');
          }
        },
      },
    },
    {
      label: '主单重量',
      field: 'wtDec',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          if (oneDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多一位小数');
          }
        },
      },
    },
    {
      label: '计费重量',
      field: 'wtChg',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          if (oneDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多一位小数');
          }
        },
      },
    },
    {
      label: '货运代理',
      field: 'agtNo',
      clo: 6,
      rules: {
        required: true,
      },
    },
    {
      type: 'input',
      label: '体积CBM',
      field: 'volDec',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          if (oneDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多一位小数');
          }
        },
      },
    },
  ];
};

export const getHaWaybillInfo = () => {
  return [
    {
      type: 'input',
      label: '分单号',
      field: 'hawbNo',
      clo: 6,
      rules: {
        required: true,
        message: '必填项不可为空',
      },
      editFlag: false,
    },
    {
      type: 'input',
      label: '分单件数',
      field: 'pcsDec',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          if (
            positiveInteger.test(value) &&
            Number(value) >= 0 &&
            Number(value) < 10000
          ) {
            callback();
          } else {
            callback('只能是正整数，并且小于10000');
          }
        },
      },
    },
    {
      type: 'input',
      label: '分单重量',
      field: 'wtDec',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          if (oneDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多一位小数');
          }
        },
      },
    },
    {
      type: 'input',
      label: '分单计费重量',
      field: 'wtChg',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          if (oneDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多一位小数');
          }
        },
      },
    },
    {
      type: 'input',
      label: '卸机目的站',
      field: 'destNo',
      clo: 12,
      rules: {
        required: true,
        message: '必填项不可为空',
      },
      editFlag: true,
    },
    {
      'type': 'input',
      'label': '分单品名',
      'field': 'goodsNameEn',
      'clo': 6,
      'max-length': 20,
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          if (GOODSNAMEEN.test(value)) {
            callback();
          } else {
            callback('英文品名只能包含大写字母、数字、点、连字符或者空格');
          }
        },
      },
    },
    {
      type: 'input',
      label: '分单体积',
      field: 'hawbvolDec',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === null || value === undefined || value === '') {
            callback('必填项不能为空');
          }
          if (oneDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多一位小数');
          }
        },
      },
    },
    {
      type: 'input',
      label: '商品编码',
      field: 'hsCode',
      clo: 24,
      editFlag: true,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是英文,英文字符或者数字');
          }
        },
      },
    },
  ];
};
/*
export const haWaybillInfo = reactive([
  {
    type: 'input',
    label: '分单号',
    field: 'hawbNo',
    clo: 6,
    rules: {
      required: true,
      message: '必填项不可为空',
    },
    editFlag: false,
  },
  {
    type: 'input',
    label: '分单件数',
    field: 'pcsDec',
    clo: 6,
    rules: {
      required: true,
      message: '必填项不可为空',
    },
  },
  {
    type: 'input',
    label: '分单重量',
    field: 'wtDec',
    clo: 6,
    rules: {
      required: true,
      message: '必填项不可为空',
    },
  },
  {
    type: 'input',
    label: '分单计费重量',
    field: 'wtChg',
    clo: 6,
    rules: {
      required: true,
      message: '必填项不可为空',
    },
  },
  {
    type: 'input',
    label: '卸机目的站',
    field: 'destNo',
    clo: 12,
    rules: {
      required: true,
      message: '必填项不可为空',
    },
    editFlag: true,
  },
  {
    'type': 'input',
    'label': '分单品名',
    'field': 'goodsNameEn',
    'clo': 6,
    'max-length': 20,
    'rules': {
      required: true,
      message: '必填项不可为空',
    },
  },
  {
    type: 'input',
    label: '分单体积',
    field: 'hawbvolDec',
    clo: 6,
    rules: {
      required: true,
      message: '必填项不可为空',
    },
  },
  {
    type: 'input',
    label: '商品编码',
    field: 'hsCode',
    clo: 24,
    editFlag: true,
  },
]);
*/

export const hawbMainWaybillInfo = [
  {
    label: '英文品名',
    field: 'mawbgoodsNameEn',
    clo: 12,
  },
  {
    type: 'input',
    label: '中文品名',
    field: 'goodsName',
    clo: 12,
  },
  { label: '主运单号', field: 'mawbNo', clo: 6 },
  {
    label: '主单件数',
    field: 'mawbpcsDec',
    clo: 6,
  },
  {
    label: '主单重量',
    field: 'mawbwtDec',
    clo: 6,
  },
  {
    label: '计费重量',
    field: 'mawbwtChg',
    clo: 6,
  },
  { label: '货运代理', field: 'mawbagtNo', clo: 6 },
  {
    label: '体积CBM',
    field: 'volDec',
    clo: 6,
  },
];

export const getFlightInfo = () => {
  return [
    {
      label: '预配航班',
      field: 'fltNo',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          } else {
            const prefix = value.substring(0, 2);
            const suffix = value.substring(2, value.length);
            if (prefix.length > 2) {
              callback('前缀最大长度两位');
            }
            if (suffix.length > 4) {
              callback('后缀最大长度四位');
            }
            if (englishAndNumber.test(value)) {
              callback();
            } else {
              callback('前缀和后缀，只能是英文或者数字');
            }
          }
        },
      },
    },
    {
      label: '起始站',
      field: 'orgnNo',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (threeEngLish.test(value)) {
            callback();
          } else {
            callback('只能是三位英文字母');
          }
        },
      },
    },
    {
      label: '卸机目的站',
      field: 'destNo',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (threeEngLish.test(value)) {
            callback();
          } else {
            callback('只能是三位英文字母');
          }
        },
      },
    },
    {
      label: '航班日期',
      field: 'fltDate',
      clo: 6,
      rules: {
        required: true,
        message: '必填项不可为空',
      },
    },
  ];
};
export const getCostInfo = (chgsList: Ref<string[]>) => {
  return [
    {
      type: 'input',
      label: '商品编码',
      field: 'hsCode',
      clo: 24,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是英文,英文字符或者数字');
          }
        },
      },
    },
    {
      type: 'select',
      label: '付款方式代码',
      field: 'wtValChgs',
      clo: 6,
      options: chgsList,
      allowCreate: true,
      rules: {
        required: true,
        message: '必填项不可为空',
      },
    },
    {
      type: 'select',
      label: '运价种类代号',
      field: 'categoryCode',
      clo: 6,
      options: ['M', 'N', 'Q', 'C', 'S', 'R', 'U', 'E', 'X', 'Y', 'W', 'C'],
      allowCreate: true,
      rules: {
        required: true,
        message: '必填项不可为空',
      },
    },
    {
      type: 'input',
      label: '费率/运费',
      field: 'rtVal',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (twoDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多两位小数');
          }
        },
      },
    },
    {
      type: 'input',
      label: '币制代码',
      field: 'curNo',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (threeEngLish.test(value)) {
            callback();
          } else {
            callback('只能是三位字母');
          }
        },
      },
    },
  ];
};

/* export const otherInfo = reactive<ShipperInfoItem[]>([
  {
    label: '运费',
    field: 'ccWtChg',
    clo: 6,
    rules: {
      required: false,
      message: '必填项不可为空',
    },
  },
  {
    label: '附加费',
    field: 'ccVlChg',
    clo: 6,
    rules: {
      required: false,
      message: '必填项不可为空',
    },
  },
  {
    label: '税费',
    field: 'ccTxChg',
    clo: 6,
    rules: {
      required: false,
      message: '必填项不可为空',
    },
  },
  {
    label: '代理人费',
    field: 'ccAgChg',
    clo: 6,
    rules: {
      required: false,
      message: '必填项不可为空',
    },
  },
  {
    label: '承运人费',
    field: 'CrChg',
    clo: 6,
    rules: {
      required: false,
      message: '必填项不可为空',
    },
  },
  {
    type: 'select',
    label: '付款方式代码',
    field: 'wtValChgs',
    clo: 8,
    options: chgsList,
    allowCreate: true,
    rules: {
      required: true,
      message: '必填项不可为空',
    },
  },
]); */
export const otherInfo = (chgsList: Ref<string[]>) => {
  return [
    {
      label: '运费',
      field: 'ccWtChg',
      type: 'input',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (twoDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多两位小数');
          }
        },
      },
    },
    {
      label: '附加费',
      type: 'input',
      field: 'ccVlChg',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (twoDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多两位小数');
          }
        },
      },
    },
    {
      label: '税费',
      type: 'input',
      field: 'ccTxChg',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (twoDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多两位小数');
          }
        },
      },
    },
    {
      label: '代理人费',
      field: 'ccAgChg',
      type: 'input',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (twoDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多两位小数');
          }
        },
      },
    },
    {
      label: '承运人费',
      type: 'input',
      field: 'CrChg',
      clo: 6,
      rules: {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (twoDecimal.test(value) && Number(value) >= 0) {
            callback();
          } else {
            callback('只能是数字，最多两位小数');
          }
        },
      },
    },
    /*    {
      type: 'select',
      label: '其他费用付款方式',
      field: 'othChgs',
      clo: 6,
      options: chgsList,
      allowCreate: true,
      rules: {
        required: true,
        message: '必填项不可为空',
      },
    }, */
  ];
};
export const getShipperInfo = () => {
  return [
    {
      'label': '发货人名称',
      'field': 'shpName',
      'clo': 12,
      'max-length': 65,
      'placeholder': '请输入65个以内的字符',
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是英文,数字或者英文字符');
          }
        },
      },
    },
    {
      'label': '发货人地址街道',
      'field': 'shpAddr',
      'clo': 12,
      'max-length': 35,
      'placeholder': '请输入35个以内的字符',
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是英文,数字或者英文字符');
          }
        },
      },
    },
    {
      'label': '发货国家二字码',
      'field': 'shpCont',
      'clo': 6,
      'max-length': 20,
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (value && value.length > 2) {
            callback('长度不能大于两位');
          }
          if (twoEngLish.test(value)) {
            callback();
          } else {
            callback('只能是两位英文');
          }
        },
      },
    },
    {
      'label': '发货人城市',
      'field': 'shpCity',
      'clo': 6,
      'max-length': 20,
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是英文,数字或者英文字符');
          }
        },
      },
    },
    {
      'label': '电话号码',
      'field': 'shpTelNo',
      'clo': 6,
      'max-length': 20,
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是英文,数字或者英文字符');
          }
        },
      },
    },
    {
      'label': '发货邮编编码',
      'field': 'shpPostNo',
      'clo': 6,
      'max-length': 50,
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (englishAndNumber.test(value)) {
            callback();
          } else {
            callback('只能是数字或者英文');
          }
        },
      },
    },
  ];
};
export const getGooderInfo = () => {
  return [
    {
      'label': '收货人名称',
      'field': 'cneName',
      'clo': 12,
      'max-length': 65,
      'placeholder': '请输入65个以内的字符',
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是英文,数字或者英文字符');
          }
        },
      },
    },
    {
      'label': '收货人地址街道',
      'field': 'cneAddr',
      'clo': 12,
      'max-length': 35,
      'placeholder': '请输入35个以内的字符',
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是英文,数字或者英文字符');
          }
        },
      },
    },
    {
      'label': '收货国家二字码',
      'field': 'cneCont',
      'clo': 6,
      'max-length': 20,
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (value && value.length > 2) {
            callback('长度不能大于两位');
          }
          if (twoEngLish.test(value)) {
            callback();
          } else {
            callback('只能是两位英文');
          }
        },
      },
    },
    {
      'label': '收货人城市',
      'field': 'cneCity',
      'clo': 6,
      'max-length': 20,
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是英文,数字或者英文字符');
          }
        },
      },
    },
    {
      'label': '电话号码',
      'field': 'cneTelNo',
      'clo': 6,
      'max-length': 20,
      'rules': {
        required: true,
        validator(value: string, callback: (message?: string) => void) {
          if (value === '' || value === null || value === undefined) {
            callback('必填项不能为空');
          }
          if (ENGLISH_LETTER_CHARACTER_NUMBER.test(value)) {
            callback();
          } else {
            callback('只能是数字或者英文');
          }
        },
      },
    },
    {
      'label': '发货邮编编码',
      'field': 'cnePostNo',
      'clo': 6,
      'max-length': 50,
    },
  ];
};
